@@ -20,14 +20,13 @@
 
 import math
 import warnings
+from collections.abc import Hashable
+from collections.abc import Iterable
+from collections.abc import Iterator
+from collections.abc import Sequence
 from typing import Any
-from typing import Hashable
-from typing import Iterable
-from typing import Iterator
 from typing import NoReturn
 from typing import Optional
-from typing import Sequence
-from typing import Tuple
 from typing import Union
 from typing import cast
 
@@ -100,7 +99,7 @@ class _Geometry:
         return self.is_empty is False
 
     @property
-    def bounds(self) -> Union[Bounds, Tuple[()]]:
+    def bounds(self) -> Union[Bounds, tuple[()]]:
         """
         Return minimum bounding region (min x, min y, max x, max y).
 
@@ -167,8 +166,8 @@ class _Geometry:
             msg = "Empty Geometry"
             raise AttributeError(msg)
         return {
-            "type": cast(GeomType, self.geom_type),
-            "bbox": cast(Bounds, self.bounds),
+            "type": cast("GeomType", self.geom_type),
+            "bbox": cast("Bounds", self.bounds),
             "coordinates": (),
         }
 
@@ -290,7 +289,7 @@ class Point(_Geometry):
         raise DimensionError(msg)
 
     @property
-    def coords(self) -> Union[Tuple[PointType], Tuple[()]]:
+    def coords(self) -> Union[tuple[PointType], tuple[()]]:
         """Return the geometry coordinates."""
         return () if self.is_empty else (self._geoms,)
 
@@ -307,7 +306,7 @@ class Point(_Geometry):
     def __geo_interface__(self) -> GeoInterface:
         """Return the geo interface."""
         geo_interface = super().__geo_interface__
-        geo_interface["coordinates"] = cast(PointType, tuple(self._geoms))
+        geo_interface["coordinates"] = cast("PointType", tuple(self._geoms))
         return geo_interface
 
     @classmethod
@@ -341,7 +340,7 @@ class LineString(_Geometry):
 
     """
 
-    _geoms: Tuple[Point, ...]
+    _geoms: tuple[Point, ...]
 
     def __init__(self, coordinates: LineType) -> None:
         """
@@ -366,7 +365,7 @@ class LineString(_Geometry):
         return f"{self.geom_type}({self.coords})"
 
     @property
-    def geoms(self) -> Tuple[Point, ...]:
+    def geoms(self) -> tuple[Point, ...]:
         """Return the underlying geometries."""
         return self._geoms
 
@@ -374,7 +373,7 @@ class LineString(_Geometry):
     def coords(self) -> LineType:
         """Return the geometry coordinates."""
         return cast(
-            LineType,
+            "LineType",
             tuple(point.coords[0] for point in self.geoms if point.coords),
         )
 
@@ -412,23 +411,21 @@ class LineString(_Geometry):
     def from_points(cls, *args: Point) -> "LineString":
         """Create a linestring from points."""
         return cls(
-            cast(LineType, tuple(point.coords[0] for point in args if point.coords)),
+            cast("LineType", tuple(point.coords[0] for point in args if point.coords)),
         )
 
     @classmethod
     def _from_dict(cls, geo_interface: GeoInterface) -> "LineString":
         cls._check_dict(geo_interface)
-        return cls(cast(LineType, geo_interface["coordinates"]))
+        return cls(cast("LineType", geo_interface["coordinates"]))
 
     @staticmethod
-    def _set_geoms(coordinates: LineType) -> Tuple[Point, ...]:
+    def _set_geoms(coordinates: LineType) -> tuple[Point, ...]:
         geoms = []
         last_len = None
         for coord in dedupe(coordinates):
             if len(coord) != last_len and last_len is not None:
-                msg = (  # type: ignore [unreachable]
-                    "All coordinates must have the same dimension"
-                )
+                msg = "All coordinates must have the same dimension"
                 raise DimensionError(
                     msg,
                 )
@@ -515,7 +512,7 @@ class Polygon(_Geometry):
 
     """
 
-    _geoms: Tuple[LinearRing, ...]
+    _geoms: tuple[LinearRing, ...]
 
     def __init__(
         self,
@@ -581,13 +578,13 @@ class Polygon(_Geometry):
         """
         if self._geoms[1]:
             return cast(
-                PolygonType,
+                "PolygonType",
                 (
                     self.exterior.coords,
                     tuple(interior.coords for interior in self.interiors if interior),
                 ),
             )
-        return cast(PolygonType, (self.exterior.coords,))
+        return cast("PolygonType", (self.exterior.coords,))
 
     @property
     def has_z(self) -> Optional[bool]:
@@ -630,8 +627,8 @@ class Polygon(_Geometry):
         if not geo_interface["coordinates"]:
             return cls(shell=(), holes=())
         return cls(
-            shell=cast(LineType, geo_interface["coordinates"][0]),
-            holes=cast(Tuple[LineType], geo_interface["coordinates"][1:]),
+            shell=cast("LineType", geo_interface["coordinates"][0]),
+            holes=cast("tuple[LineType]", geo_interface["coordinates"][1:]),
         )
 
     def _get_bounds(self) -> Bounds:
@@ -703,7 +700,7 @@ class MultiPoint(_MultiGeometry):
 
     """
 
-    _geoms: Tuple[Point, ...]
+    _geoms: tuple[Point, ...]
 
     def __init__(self, points: Sequence[PointType], unique: bool = False) -> None:
         """
@@ -746,7 +743,7 @@ class MultiPoint(_MultiGeometry):
     @property
     def geoms(self) -> Iterator[Point]:
         """Iterate over the points."""
-        yield from (cast(Point, p) for p in super().geoms)
+        yield from (cast("Point", p) for p in super().geoms)
 
     @property
     def _wkt_coords(self) -> str:
@@ -772,7 +769,7 @@ class MultiPoint(_MultiGeometry):
     @classmethod
     def _from_dict(cls, geo_interface: GeoInterface) -> "MultiPoint":
         cls._check_dict(geo_interface)
-        return cls(cast(Sequence[PointType], geo_interface["coordinates"]))
+        return cls(cast("Sequence[PointType]", geo_interface["coordinates"]))
 
     def _prepare_hull(self) -> Iterable[Point2D]:
         return ((pt.x, pt.y) for pt in self.geoms)
@@ -791,7 +788,7 @@ class MultiLineString(_MultiGeometry):
 
     """
 
-    _geoms: Tuple[LineString, ...]
+    _geoms: tuple[LineString, ...]
 
     def __init__(self, lines: Sequence[LineType], unique: bool = False) -> None:
         """
@@ -827,7 +824,7 @@ class MultiLineString(_MultiGeometry):
     @property
     def geoms(self) -> Iterator[LineString]:
         """Iterate over the points."""
-        yield from (cast(LineString, line) for line in super().geoms)
+        yield from (cast("LineString", line) for line in super().geoms)
 
     @property
     def _wkt_coords(self) -> str:
@@ -855,7 +852,7 @@ class MultiLineString(_MultiGeometry):
     @classmethod
     def _from_dict(cls, geo_interface: GeoInterface) -> "MultiLineString":
         cls._check_dict(geo_interface)
-        return cls(cast(Sequence[LineType], geo_interface["coordinates"]))
+        return cls(cast("Sequence[LineType]", geo_interface["coordinates"]))
 
     def _prepare_hull(self) -> Iterable[Point2D]:
         for geom in self.geoms:
@@ -876,7 +873,7 @@ class MultiPolygon(_MultiGeometry):
 
     """
 
-    _geoms: Tuple[Polygon, ...]
+    _geoms: tuple[Polygon, ...]
 
     def __init__(self, polygons: Sequence[PolygonType], unique: bool = False) -> None:
         """
@@ -935,7 +932,7 @@ class MultiPolygon(_MultiGeometry):
     @property
     def geoms(self) -> Iterator[Polygon]:
         """Iterate over the points."""
-        yield from (cast(Polygon, p) for p in super().geoms)
+        yield from (cast("Polygon", p) for p in super().geoms)
 
     @property
     def _wkt_coords(self) -> str:
@@ -964,7 +961,7 @@ class MultiPolygon(_MultiGeometry):
             (poly[0], poly[1:])  # type: ignore [index]
             for poly in geo_interface["coordinates"]
         )
-        return cls(cast(Sequence[PolygonType], coords))
+        return cls(cast("Sequence[PolygonType]", coords))
 
     def _prepare_hull(self) -> Iterable[Point2D]:
         for geom in self.geoms:
@@ -1012,7 +1009,7 @@ class GeometryCollection(_MultiGeometry):
 
     """
 
-    _geoms: Tuple[Union[Geometry, "GeometryCollection"], ...]
+    _geoms: tuple[Union[Geometry, "GeometryCollection"], ...]
 
     def __init__(
         self,
